/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.sensor.fritzmeijer;

import java.io.IOException;
import java.util.logging.Logger;
import nl.cloudfarming.client.sensor.SensorDataObject;
import nl.cloudfarming.client.sensor.SensorProcessor;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.text.MultiViewEditorElement;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataObjectExistsException;
import org.openide.loaders.MultiFileLoader;
import org.openide.util.HelpCtx;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.TopComponent;

public class FritzmeijerDataObject extends SensorDataObject {

    private static final Logger LOG = Logger.getLogger("nl.cloudfarming.client.sensor.fritzmeijer.FritzmeijerDataObject");
    private FritzmeijerFileProcessor processor = null;

    public FritzmeijerDataObject(FileObject pf, MultiFileLoader loader) throws DataObjectExistsException, IOException {
        super(pf, loader);
        
        LOG.info("FritzmeijerDataObject constructor");
        registerEditor("text/csv-fritzmeijer", true);
    }

    @Override
    protected int associateLookup() {
        return 1;
    }
    
    @Override
    public HelpCtx getHelpCtx () {
        return new HelpCtx("nl.cloudfarming.client.sensor.fritzmeijer.about");
    }

    @MultiViewElement.Registration(displayName = "#LBL_Fritzmeijer_EDITOR",
    iconBase = "nl/cloudfarming/client/sensor/fritzmeijer/file_extension_qxd.png",
    mimeType = "text/csv-fritzmeijer",
    persistenceType = TopComponent.PERSISTENCE_ONLY_OPENED,
    preferredID = "Fritzmeijer",
    position = 200)
    @Messages("LBL_Fritzmeijer_EDITOR=Source")
    public static MultiViewEditorElement createEditor(Lookup lkp) {
        return new MultiViewEditorElement(lkp);
    }

    @Override
    protected SensorProcessor getProcessor() {
        if (processor == null) {
          processor = new FritzmeijerFileProcessor(this);
        }
        return processor;
    }
}
